==> akasha-j2cl-0.21-sources.jar: akasha/Akasha.js <==
/**
 * @fileoverview
 * @suppress {useOfGoogProvide}
 */
/**
 * @suppress {lintChecks}
 * @const
 */
var goog = goog || {};
goog.provide('akasha.Akasha');

/** @define {string} */
akasha.is__Window_speechSynthesis__supported = goog.define('akasha.is__Window_speechSynthesis__supported', 'detect');

/** @define {string} */
akasha.is__Window_indexedDB__supported = goog.define('akasha.is__Window_indexedDB__supported', 'detect');

/** @define {string} */
akasha.is__Window_localStorage__supported = goog.define('akasha.is__Window_localStorage__supported', 'detect');

/** @define {string} */
akasha.is__Window_sessionStorage__supported = goog.define('akasha.is__Window_sessionStorage__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_clipboard__supported = goog.define('akasha.is__Navigator_clipboard__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_credentials__supported = goog.define('akasha.is__Navigator_credentials__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_geolocation__supported = goog.define('akasha.is__Navigator_geolocation__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_mediaDevices__supported = goog.define('akasha.is__Navigator_mediaDevices__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_permissions__supported = goog.define('akasha.is__Navigator_permissions__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_wakeLock__supported = goog.define('akasha.is__Navigator_wakeLock__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_serviceWorker__supported = goog.define('akasha.is__Navigator_serviceWorker__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_bluetooth__supported = goog.define('akasha.is__Navigator_bluetooth__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_xr__supported = goog.define('akasha.is__Navigator_xr__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_gpu__supported = goog.define('akasha.is__Navigator_gpu__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_sendBeacon__supported = goog.define('akasha.is__Navigator_sendBeacon__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_requestMediaKeySystemAccess__supported = goog.define('akasha.is__Navigator_requestMediaKeySystemAccess__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_getGamepads__supported = goog.define('akasha.is__Navigator_getGamepads__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_vibrate__supported = goog.define('akasha.is__Navigator_vibrate__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_share__supported = goog.define('akasha.is__Navigator_share__supported', 'detect');

==> akasha-j2cl-0.25-sources.jar: akasha/Akasha.js <==
/**
 * @fileoverview
 * @suppress {useOfGoogProvide}
 */
/**
 * @suppress {lintChecks}
 * @const
 */
var goog = goog || {};
goog.provide('akasha.Akasha');

/** @define {string} */
akasha.is__WorkerNavigator_gpu__supported = goog.define('akasha.is__WorkerNavigator_gpu__supported', 'detect');

/** @define {string} */
akasha.is__Window_speechSynthesis__supported = goog.define('akasha.is__Window_speechSynthesis__supported', 'detect');

/** @define {string} */
akasha.is__Window_indexedDB__supported = goog.define('akasha.is__Window_indexedDB__supported', 'detect');

/** @define {string} */
akasha.is__Window_localStorage__supported = goog.define('akasha.is__Window_localStorage__supported', 'detect');

/** @define {string} */
akasha.is__Window_sessionStorage__supported = goog.define('akasha.is__Window_sessionStorage__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_clipboard__supported = goog.define('akasha.is__Navigator_clipboard__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_credentials__supported = goog.define('akasha.is__Navigator_credentials__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_geolocation__supported = goog.define('akasha.is__Navigator_geolocation__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_mediaDevices__supported = goog.define('akasha.is__Navigator_mediaDevices__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_permissions__supported = goog.define('akasha.is__Navigator_permissions__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_wakeLock__supported = goog.define('akasha.is__Navigator_wakeLock__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_serviceWorker__supported = goog.define('akasha.is__Navigator_serviceWorker__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_bluetooth__supported = goog.define('akasha.is__Navigator_bluetooth__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_xr__supported = goog.define('akasha.is__Navigator_xr__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_gpu__supported = goog.define('akasha.is__Navigator_gpu__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_sendBeacon__supported = goog.define('akasha.is__Navigator_sendBeacon__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_requestMediaKeySystemAccess__supported = goog.define('akasha.is__Navigator_requestMediaKeySystemAccess__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_getGamepads__supported = goog.define('akasha.is__Navigator_getGamepads__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_vibrate__supported = goog.define('akasha.is__Navigator_vibrate__supported', 'detect');

/** @define {string} */
akasha.is__Navigator_share__supported = goog.define('akasha.is__Navigator_share__supported', 'detect');

/** @define {string} */
akasha.is__WorkerGlobalScope_indexedDB__supported = goog.define('akasha.is__WorkerGlobalScope_indexedDB__supported', 'detect');
